@@ -388,14 +388,29 @@ def testLEDETnotebook():
 
 def test_persCurrents():
     a = ParametersLEDET()
-    a.readLEDETExcel( "C:\cernbox\SWAN_projects\steam-notebooks\steam-ledet-input\MO_1AP\MO_1AP_8magBB_0.xlsx")
-    a.Inputs.fitParameters_inGroup = np.ones((3, 16))
-    a.Inputs.df_inGroup = np.ones((16,)).transpose()
-    a.Inputs.selectedFit_inGroup = np.ones((16,)).transpose()
+    a.readLEDETExcel( "C:\cernbox\SWAN_projects\steam-notebooks\steam-ledet-input\MQXF_V2\MQXF_V2_0.xlsx")
+    a.Inputs.fitParameters_inGroup = np.ones((3, 32))
+    a.Inputs.df_inGroup = np.ones((32,)).transpose()
+    a.Inputs.selectedFit_inGroup = np.ones((32,)).transpose()
     # a.Options.flag_persistentCurrents = 1
     a.writeFileLEDET('A.xlsx')
     return a
 
+def test_persCurrents2():
+    a = ParametersLEDET()
+    a.readLEDETExcel( "C:\cernbox\SWAN_projects\steam-notebooks\steam-ledet-input\MQXF_V2\MQXF_V2_0.xlsx")
+    dIdt = 6.8
+    timeStep = 0.5
+
+    nameFileLEDET_PS = 'abc_200' + '.xlsx'
+    PS_paramLEDET = deepcopy(a)
+    PS_paramLEDET.localsParser(locals())
+    I00 = a.Inputs.I00
+    I_PC_LUT = [0, 0, I00, I00, -I00, -I00, I00, I00, -I00, -I00, 0, 0]
+    PS_paramLEDET.preparePersistentCurrents(I_PC_LUT, dIdt, timeStep)
+    PS_paramLEDET.writeFileLEDET(nameFileLEDET_PS)
+    return a
+
 def testOldLEDETnotebook():
     from steam_nb_api.ledet.NotebookLEDET import NB_LEDET as nl
     nameMagnet = "MainSolenoid"  # coil name in imput folder
@@ -458,20 +473,33 @@ def testSolenoids():
     return new_notebook
 
 def testMP3():
-    ParameterFile = "600A_Circuit_Param_Table.csv"
-    MP3 = MP3_setup('600A', 'RSS.A78B1', ParameterFile)
-    MP3.load_config('MarvinJ')
-    MP3.SetUpSimulation('FPA', 250)
+    Opts = Options()
+    Opts.t_0 = [0, 1.5, 2]
+    Opts.t_end = [1.5, 2, 3]
+    Opts.t_step_max = [[0.0005, 0.0005, 0.001]] + [[0.0005, 0.0005, 0.001]] * 2
+    Opts.relTolerance = [1e-4] + [None] * 2
+    Opts.absTolerance = [1] + [None] * 2
+    Opts.executionOrder = [1] + [2] * 2
+    Opts.executeCleanRun = [True] * (2 + 1)
 
+    # ParameterFile = "600A_Circuit_Param_Table.csv"
+    # MP3 = MP3_setup('RSS.A81B1', ParameterFile, Opts = Opts, enableQuench=0)
+    # MP3.load_config('MarvinJ')
+    # MP3.SetUpSimulation('FPA', 250)
+    ParameterFile = "IPQ_Circuit_Param_Table.csv"
+    MP3 = MP3_setup("RQ4.L2", ParameterFile)
+    MP3.load_config('MarvinJ')
+    MP3.SetUpSimulation('unbalancedFPA', [[250, 500]],
+                        ManualCircuit="C:\\cernbox\\SWAN_projects\\steam-notebooks\\steam-sing-input\\IPQ\\IPQ_MagnetEQ4.cir")
     return MP3
 
-# a = test_persCurrents()
+# a = test_persCurrents2()
 
 # nb = testOldLEDETnotebook()
 
 # nb = testSolenoids()
 
-nb = testMP3()
+# nb = testMP3()
 
 # nb= testLEDETnotebook()
 
@@ -479,8 +507,14 @@ nb = testMP3()
 
 # testConsistencyChecks()
 
-# CompareLEDETParameters("C:\cernbox\MB_1.xlsx","C:\cernbox\MB_65.xlsx")
 
+CompareLEDETParameters("C:\cernbox\SWAN_projects\steam-notebooks\steam-ledet-input\MQ_1AP\MQ_1AP_0.xlsx",
+                       "S:\LHC\RQD_RQF\ElMaTh\LEDET\LEDET\MQ\Input\MQ_1.xlsx")
+# CompareLEDETParameters("C:\cernbox\MB_1.xlsx","C:\cernbox\MB_65.xlsx")
+# CompareLEDETParameters("C:\cernbox\MQXA_200.xlsx","C:\cernbox\SWAN_projects\steam-notebooks\steam-ledet-input\MQXA\MQXA_200.xlsx")
+
+# CompareLEDETParameters("C:\cernbox\COSIM\Models\COSIM_model_RQ9.L1_unbalancedFPA_5225A5225A\LEDET_2\LEDET\MQMC_2in1\Input\MQMC_2in1_0.xlsx",
+#                        "S:\LHC\IPQ\ElMaTh\PSPICE_LEDET\Output\Test_31\\3_LEDET\Model\LEDET\MQMC_2in1\Input\MQMC_2in1_0.xlsx")
 # CompareLEDETParameters("C:\cernbox\LEDET_MT\LEDET\MQXFS4b\Input\MQXFS4b_0.xlsx", "C:\cernbox\MasterThesis\QuenchPlans\MQXF_V2_2924.xlsx")
 # CompareLEDETParameters("C:\\cernbox\\steam-notebook-api\\test\\ledet\\resources\\TestFile_1.xlsx", "C:\\cernbox\\steam-notebook-api\\test\\ledet\\TestFile1.xlsx")
 # CompareLEDETParameters("C:\cernbox\MasterThesis\QuenchPlans\MQXF_V2_5400.xlsx", "C:\cernbox\LEDET_MT\LEDET\MQXFS4b\Input\MQXFS4b_14.xlsx")
