@@ -82,7 +82,7 @@ class MagneticCoil:
 
         firstRowBlock = fileContentByRow[startOfBlockIndex]
         nRowsBlockParameters = int(firstRowBlock[5:])
-        print('Block definition parameters have {} rows'.format(nRowsBlockParameters))
+        if verbose: print('Block definition parameters have {} rows'.format(nRowsBlockParameters))
 
         # Separate part of the data with block definition information
         blockParameters = fileContentByRow[startOfBlockIndex + 1:startOfBlockIndex + 1 + nRowsBlockParameters]
@@ -153,9 +153,9 @@ class MagneticCoil:
         firstRowGroup = fileContentByRow[startOfGroupIndex]
         nRowsGroupParameters = int(firstRowGroup[5:])
         if nRowsGroupParameters == 1:
-            print('Group definition parameters have {} row'.format(nRowsGroupParameters))
+            if verbose: print('Group definition parameters have {} row'.format(nRowsGroupParameters))
         else:
-            print('Group definition parameters have {} rows'.format(nRowsGroupParameters))
+            if verbose: print('Group definition parameters have {} rows'.format(nRowsGroupParameters))
 
         # Separate part of the data with group definition information
         groupParameters = fileContentByRow[startOfGroupIndex + 1:startOfGroupIndex + 1 + nRowsGroupParameters]
@@ -215,9 +215,9 @@ class MagneticCoil:
         firstRowTransformation = fileContentByRow[startOfTransformationIndex]
         nRowsTransformationParameters = int(firstRowTransformation[5:])
         if nRowsTransformationParameters == 1:
-            print('Transformation definition parameters have {} row'.format(nRowsTransformationParameters))
+            if verbose: print('Transformation definition parameters have {} row'.format(nRowsTransformationParameters))
         else:
-            print('Transformation definition parameters have {} rows'.format(nRowsTransformationParameters))
+            if verbose: print('Transformation definition parameters have {} rows'.format(nRowsTransformationParameters))
 
         # Separate part of the data with transformation definition information
         transformationParameters = fileContentByRow[
