@@ -125,7 +125,7 @@ class MP3_setup:
 
         return parameter_dict
 
-    def SetUpSimulation(self, transient, Current, Append: bool = False, ManualCircuit: str = '', ManualStimuli: list = []):
+    def SetUpSimulation(self, transient, Current, Append: bool = False, ManualCircuit: str = '', ManualStimuli: list = [], AppendStimuli = ''):
         self.transient = transient
         parameter_dict = self._loadParameterFile()
 
@@ -155,7 +155,7 @@ class MP3_setup:
                 CoilSections = json.loads(parameter_dict['CoilSections'])
                 if not ManualCircuit: circuit_file = self.__findCircuit(self.circuit)
                 else: circuit_file = ManualCircuit
-                COSIMfolder = self._setUp_COSIM(N_LEDET, CoilSections, circuit_file, parameter_dict)
+                COSIMfolder = self._setUp_COSIM(N_LEDET, CoilSections, circuit_file, parameter_dict, AppendStimuli = AppendStimuli)
             else:
                 COSIMfolder = self._setUp_LEDETonly(parameter_dict)
             Folder.append(COSIMfolder)
@@ -245,7 +245,7 @@ class MP3_setup:
                         return os.path.join(self.path_NotebookLib,'steam-sing-input',f,k)
         print('No circuit file found for' + circuitName + ' [' + fam + '] ')
 
-    def __generateStimuliCOSIM(self, StimulusFile, transient, current_level, t_Start, t_PC):
+    def __generateStimuliCOSIM(self, StimulusFile, transient, current_level, t_Start, t_PC, AppendStimuli):
         if transient == 'FPA' and not self.ManualStimuli:
             Stimuli =  "I_FPA_" + str(current_level)
             stlString = ".STIMULUS I_FPA_" + str(current_level) + " PWL" + "\n"
@@ -294,9 +294,19 @@ class MP3_setup:
         else:
             print('Transient is not supported yet. Abort!')
             return
+        if AppendStimuli:
+            stlString = ''
+            with open(StimulusFile, 'a') as file:
+                with open(AppendStimuli, 'r') as apSt:
+                    for line in apSt:
+                        if 't_PC' in line: line = line.replace('**t_PC** ', str(t_PC))
+                        if 't_PC+0.001' in line: line = line.replace('**t_PC+0.001** ', str(t_PC+0.001))
+                        stlString = stlString + line
+                file.write(stlString)
+
         return Stimuli
 
-    def _setUp_COSIM(self, N_LEDET, CoilSections, circuit, parameter_dict):
+    def _setUp_COSIM(self, N_LEDET, CoilSections, circuit, parameter_dict, AppendStimuli = ''):
         current_level = parameter_dict['I00']
         try:
             MagnetName = json.loads(parameter_dict['MagnetName'])
@@ -318,7 +328,7 @@ class MP3_setup:
         ModelFolder_EOS = os.path.join(self.ModelFolder_EOS, 'COSIM_model_' + self.circuit + "_" + self.transient + "_" +
                                             str(cl) +quenchTitle)
         ModelFolder_C = self.ModelFolder + 'COSIM_model_' + self.circuit + "_" + self.transient + "_" + str(cl) +quenchTitle
-        ResultFolder_C = self.ResultFolder + self.circuit + "_" + self.transient + "_" + str(cl) +quenchTitle+'\\'
+        ResultFolder_C = self.ResultFolder + self.circuit + "_" + self.transient + "_" + str(cl) +quenchTitle+'\\Output\\'
         COSIMfolder = ModelFolder_C
 
         if len(MagnetName)!= N_LEDET: Magnets = [MagnetName] * N_LEDET
@@ -351,7 +361,7 @@ class MP3_setup:
         StimulusFile =  os.path.join(ModelFolder_EOS, 'PSpice','ExternalStimulus.stl')
         t_Start = parameter_dict['t_Start']
         t_PC = parameter_dict['t_PC']
-        Stimuli = self.__generateStimuliCOSIM(StimulusFile, self.transient, current_level, t_Start, t_PC)
+        Stimuli = self.__generateStimuliCOSIM(StimulusFile, self.transient, current_level, t_Start, t_PC, AppendStimuli)
 
         # 4. Change .cir file
         self.__manipulateCircuit(new_circuit, parameter_cir, Stimuli)
